#   Gabe's muttrc (zach@igd.fhg.de)
#
#   Make mutt's bindings as close to lynx', slrn's, and vim's as possible
#
#   Date: Fri Jan 21 09:59:18 MET 2000


#
#  Aliases
#

source ~/.aliases
source ~/.mutt/aliases


# ask if msg has not been modified
set abort_unmodified=ask-yes

# file for new aliases
set alias_file=~/.mutt/aliases

# other "me"s
set alternates="Gabriel.Zachmann@igd.fhg.de"

# ask for cc:'s before editing
set askcc

# use ASC chars to display threading
unset ascii_chars

# don't write "On ... wrote:" at the beginning of an included msg
set attribution=""

# apply operation always to all tagged messages
set auto_tag

# no beeps
unset beep
unset beep_new

# always make a copy of outgoing msgs
set copy

# don't ask whether or not to really delete messages marked for deletion
set delete=yes

# make headers editable, too
set edit_headers

# use vim, of course, to edit messages
set editor="vim -c '/^$/'"

# Ignore header fields
ignore Content- Mime-Version X-Unsub X-List \
	   Precedence X-Listprocessor-Version Errors-To X-Comment \
	   Lines X-mailing-list X-loop X-MSMail-Priority X-MimeOLE \
	   X-Http-Proxy X-Accept-Language X-Flags \
	   Received Message-Id 

# don't ask so much when replying or forwarding
set fast_reply

# where folders are
set folder=/igd/a4/homem3/zach/Mail
# keep folders on imap server
#set folder="{igdmail}"
# maybe, one could define a macro or something, which one could
# change the value of this variable, so that one could have
# folders in the home as well as on the imap server ...

# subject line of forwarded msgs
set forward_format="(fwd) %s"

# I want a long history
set history=100

set hostname="igd.fhg.de"

# check every 10 minutes for new mail when using imap
set imap_checkinterval=600

set imap_user="zach"

# always include a msg in the reply
set include=yes

# indent interpolated msgs by "
set indent_string='" '

# check for new mail every 10 minutes when using mailbox files
set mail_check=600

# remove my address from address lists when replying to multiple recipients
unset metoo

# don't move read messages
set move=no

# mail's stay on "New" status
set nomark_old

# don't go to the next message after paging thru the current
set pager_stop

# try to pgp/mime decode msgs first before piping them
set pipe_decode

# folder for postponed msgs
set postponed=+Postponed

# command for printing
set print_command="a2ps -1 --portrait --borders=no --pretty-print=mail --highlight-level=heavy -P prt1o1"

# ldap query script
set query_command = "/igd/a4/homem3/zach/bin/mutt_ldap_query2.pl '%s'"

# ask before quitting
set quit=ask-yes

# 
set realname="Gabriel Zachmann"

# folder for copies of outgoing mail
set record="+Sent-`date +%Y-%m`"

# more "reply" prefixes (will be removed for threading)
set reply_regexp="^((re(\\^[0-9])? ?:|a(nt)?w(ort)?:|\\(fwd\\))[ \t]+)*"

# special strings which do *not* denote quoted material
# see also the 'color' commands
set smileys="(>From )|(>?[;:][-^]?[][)(><}{|/DP][)}]*)"

set shell="csh -f"

# sort by thread, then by date
set sort=threads
set sort_aux=date-sent

# incoming mailbox (imap server); default is $MAIL
set spoolfile="{igdmail}"

# you can have several incoming mailboxes ("inboxes")
#mailboxes {igdmail} /igd/a4/mail/zach

# status at the top of the screen
set status_on_top

# mark only msgs cc'ed to me, and from me
# (don't mark those which are addressed only to me, because almost all are )
set to_chars="  CF"


#
# Hooks
#

# special record folders, all other outgoing mail will be saved in $record
fcc-save-hook bmw.de$ +bmw
fcc-save-hook tecnomatix +robcad
fcc-save-hook volkswagen.de$ +vw
fcc-save-hook vd3-d +vd3
fcc-save-hook vd2-support +vd2-support
fcc-save-hook lididawn +l
fcc-save-hook texnology.com +latex-style
fcc-save-hook alain.nadeau +latex-style
fcc-save-hook ahmed@hindawi.com +latex-style
fcc-save-hook ichbin@physik.tu-muenchen.de +latex-style
fcc-save-hook kaveh@focal.demon.co.uk +latex-style
fcc-save-hook yin@asc.on.ca +latex-style

save-hook '~h Originator:\ vd2-support' +vd2-support
save-hook '~B call\ for\ papers' +events


#
# Mailing lists
#

lists vd3-d vd2-support plan compgeom-discuss general@eg.org
lists hgdv-intern ankuendigungen a4@igd.fhg.de


#
# Special headers
#

# from zmail
#my_hdr X-Face: *cJ~vhJ%_[BEAiij5<1Rp5s]Ms'*va-L79d%}^EH]J9WDeK^HQb*rRV1_rAH"'"IZuR!qv61v,vDH@nV%UH8'"'k7,-ow'21tvO1lrJ/vD@~.AxV1I0G=QH\&X/"'"CqQ@oE}y1W5|SO<E;u.FWYc+vU&_,Iw}5><E@uENCb>q!ZQ-5!9U+b%XKjS5'

#my_hdr X-Face:  =^Afm:KEFSTBVuHJ'Twv@||\#\>Nz\`A%%M$~dDLkHi7Z_Cu5q)4"aUSTM*X1V\#\;um5Sq{0jTr'v&P$!IOZC&^hL$vmauH6Sc}|Tb>ju=qi\;&EXL$?p$b($ETsk\%IEGUX)k\`r<HM\#atD7B[G9\;|9Bm4''q>_octzlLS!?xy/"

my_hdr Organization: Fraunhofer Inst. for Computer Graphics, Darmstadt, Germany

# order in wich headers to display
hdr_order From: Subject: Date: Cc: To:


#
#   Macros
#

#  save messages to folder (defined by save-hook) without confirmation
macro pager S s\n "Save without confirmation"
macro index S s\n "Save without confirmation"

#  view x-face
macro pager	\ef	"|view-x-face\n" "View X-Face"

#  extract url's from messages, present menu, and start browser
macro index U ":set pipe_decode\n|urlview\n:unset pipe_decode\n" "extract URLs out of a message"
macro pager U ":set pipe_decode\n|urlview\n:unset pipe_decode\n" "extract URLs out of a message"

#  view attachment using less
macro attach l "|less\n" "View plain message using less"

#  help
macro generic <F1> "!lynx /hgdv/software/doc/mutt/index.html\n" "view help with lynx"
macro index   <F1> "!lynx /hgdv/software/doc/mutt/index.html\n" "view help with lynx"
macro pager   <F1> "!lynx /hgdv/software/doc/mutt/index.html\n" "view help with lynx"

#  turn all O's in N's
macro index \eN "T~O\nN\Ct*\n" "turn all O's in N's"


#
#   Key bindings
#   Make mutt's bindings as close to lynx', slrn's, and vim's as possible
#

# move 1/2 page up/down like in vi
bind generic \Cu half-up
bind generic \Cd half-down
bind pager   \Cu half-up
bind pager   \Cd half-down
bind generic   b previous-page
bind generic \Cb previous-page
bind generic \Cf next-page
bind generic 1G     first-entry
bind generic <Home> first-entry
bind generic \Ca    first-entry
bind generic G      last-entry
bind generic <End>  last-entry
bind generic \Ce    last-entry

bind pager   \eD delete-thread
bind pager   \eU undelete-thread
# ^U and ^D were bound otherwise, so bind it now again to something else
bind pager \Ca    top
bind pager <Home> top
bind pager  1G    top
bind pager \Ce   bottom
bind pager <End> bottom
bind pager   G   bottom
bind pager   q exit
bind pager   i noop
bind pager   B bounce-message
bind pager   b previous-page
bind pager \Cb previous-page
bind pager \Cf next-page

bind index   \eD delete-thread
bind index   \eU undelete-thread
# ^U and ^D were bound otherwise, so bind it now again to something else
bind index   B bounce-message
bind index \ef forget-passphrase
bind index \Cb previous-page
bind index \Cf next-page
bind index <Up> previous-entry
bind index <Down> next-entry
bind index <Right> display-message
bind index <Home> first-entry
bind index <End>  last-entry

bind alias <Tab> next-entry

bind browser <Right> select-entry


#
#   Color
#   Tuned for white background
#

color normal		default		default

color hdrdefault	red			default
color signature		blue		default
color indicator		black		brightred
color error			brightred	default
color status		white		blue
color tree			magenta		default # the thread tree in the index menu
color tilde			magenta		default
color message		cyan		default
color markers		cyan		default
color attachment	brightmagenta default
color search		default		green   # how to hilite searches in the pager
color quoted		blue		default # quoted text
color quoted1		magenta		default
color quoted2		red			default
color quoted3		green		default
color quoted4		cyan		default
color quoted5		blue		default
color quoted6		magenta		default
color quoted7		red			default
color quoted8		green		default
color quoted9		cyan		default
color underline		brightgreen default
color index			green default ~F

color header		brightred	default ^(From|Subject):
# point out url's
color body			magenta		default "((ftp|http|https)://|(file|news):|www\\.)[-a-z0-9_.:]*[a-z0-9](/[^][{} \t\n\r\"<>()]*[^][{} \t\n\r\"<>().,:!])?/?"
color body			cyan		default [-a-z_0-9.]+@[-a-z_0-9.]+    # e-mail addresses

# smilies and the like
color body brightgreen white "<[Gg]>"
color body brightgreen white "<[Bb][Gg]>"
# see also the variables smileys
color body brightgreen white " >?[;:][-^]?[][)(><}{|/DP][)}]*"

#
#  Mono
#

mono normal             none            # normal text
mono indicator          reverse         # actual message
mono tree               none            # thread arrows
mono status             reverse         # status line
mono error              bold
mono message            none            # info messages
mono quoted             bold
mono signature          none
mono attachment         underline       # MIME attachments
mono search             reverse         # search matches
mono tilde              none            # ~ at bottom of msg
mono markers            bold            # + at beginning of wrapped lines
mono hdrdefault         none            # default header lines
mono bold               bold            # hiliting bold patterns in body
mono underline          underline       # hiliting underlined patterns in body
mono header      		bold           "^(from|subject):"
mono body        		underline      "((ftp|http|https)://|(file|mailto|news):|www\\.)[-a-z0-9_.:]*[a-z0-9](/[^][{} \t\n\r\"<>()]*[^][{} \t\n\r\"<>().,:!])?/?"
mono body        		underline      "[-a-z_0-9.]+@[-a-z_0-9.]+"
mono body        		bold           "(^| )\\*[-a-z0-9*]+\\*[,.?]?[ \n]"
mono body        		underline      "(^| )_[-a-z0-9_]+_[,.?]?[ \n]"



#
#   Attachment handling
#

auto_view text/html text/enriched text/x-vcard application/x-zip-compressed
alternative_order text/plain text/html


#
#   Startup
#   Things to be done at startup of mutt.
#

#  display mutt version
#  there is a bug in mutt-1.1.1 which inserts this 'V' as the first char 
#  of the password for the imap server.
#push V

